@@ -12,11 +12,7 @@ class RespuestaElement(object):
             etree.QName(PRAXIS_NS, 'respuesta'),
             nsmap={None: PRAXIS_NS},
         )
-        mensaje = etree.tostring(
-            element,
-            xml_declaration=True,
-            encoding='cp850',
-        )
+        mensaje = etree.tostring(element, xml_declaration=True, encoding='cp850')
         respuesta.text = mensaje
         return respuesta
 
@@ -41,4 +37,4 @@ class RespuestaRequest(object):
         envelope = RespuestaElement(mensaje.build_xml())
         if not as_string:
             return envelope
-        return etree.tostring(envelope, xml_declaration=True)
+        return etree.tostring(envelope, xml_declaration=True, encoding='utf-8')
